@@ -11,6 +11,7 @@ use libc;
 use markup5ever::LocalName;
 
 use crate::allowed_url::Fragment;
+use crate::node::RsvgNode;
 use crate::parsers::ParseError;
 
 /// A simple error which refers to an attribute's value
@@ -123,25 +124,13 @@ impl From<cairo::Status> for RenderingError {
     }
 }
 
-#[derive(Debug)]
 pub enum AcquireError {
     LinkNotFound(Fragment),
     InvalidLinkType(Fragment),
-    CircularReference(Fragment),
+    CircularReference(RsvgNode),
     MaxReferencesExceeded,
 }
 
-impl error::Error for AcquireError {
-    fn description(&self) -> &str {
-        match *self {
-            AcquireError::LinkNotFound(_) => "link not found",
-            AcquireError::InvalidLinkType(_) => "link is to object of invalid type",
-            AcquireError::CircularReference(_) => "circular reference in link",
-            AcquireError::MaxReferencesExceeded => "maximum number of references exceeded",
-        }
-    }
-}
-
 impl fmt::Display for AcquireError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match *self {
@@ -151,11 +140,11 @@ impl fmt::Display for AcquireError {
             AcquireError::InvalidLinkType(ref frag) =>
                 write!(f, "link {} is to object of invalid type", frag),
 
-            AcquireError::CircularReference(ref frag) =>
-                write!(f, "circular reference in link {}", frag),
+            AcquireError::CircularReference(ref node) =>
+                write!(f, "circular reference in node {}", node),
 
             AcquireError::MaxReferencesExceeded =>
-                write!(f, "{}", self.description()),
+                write!(f, "maximum number of references exceeded"),
         }
     }
 }
