@@ -108,12 +108,8 @@ impl Filter for Blend {
         let output_surface = input_2.surface().copy_surface(bounds)?;
         {
             let cr = cairo::Context::new(&output_surface);
-            cr.rectangle(
-                bounds.x0 as f64,
-                bounds.y0 as f64,
-                (bounds.x1 - bounds.x0) as f64,
-                (bounds.y1 - bounds.y0) as f64,
-            );
+            let r = cairo::Rectangle::from(bounds);
+            cr.rectangle(r.x, r.y, r.width, r.height);
             cr.clip();
 
             input.surface().set_as_source_surface(&cr, 0f64, 0f64);
