@@ -45,9 +45,8 @@ impl Image {
         fragment: &Fragment,
     ) -> Result<ImageSurface, FilterError> {
         let acquired_drawable = draw_ctx
-            .acquired_nodes()
-            .get_node(fragment)
-            .ok_or(FilterError::InvalidInput)?;
+            .acquire_node(fragment, &[])
+            .map_err(|_| FilterError::InvalidInput)?;
         let drawable = acquired_drawable.get();
 
         let surface = ImageSurface::create(
