@@ -1,6 +1,6 @@
 use std::cmp::{max, min};
 
-use cairo::{self, ImageSurface, MatrixTrait};
+use cairo::{self, ImageSurface};
 use markup5ever::{local_name, LocalName};
 
 use crate::drawing_ctx::DrawingCtx;
