@@ -488,9 +488,9 @@ impl UnresolvedGradient {
     }
 
     fn resolve_from_defaults(&self) -> UnresolvedGradient {
-        let units = self.units.or(Some(GradientUnits::default()));
-        let affine = self.affine.or(Some(cairo::Matrix::identity()));
-        let spread = self.spread.or(Some(SpreadMethod::default()));
+        let units = self.units.or_else(|| Some(GradientUnits::default()));
+        let affine = self.affine.or_else(|| Some(cairo::Matrix::identity()));
+        let spread = self.spread.or_else(|| Some(SpreadMethod::default()));
         let stops = self.stops.clone().or_else(|| Some(Vec::<ColorStop>::new()));
         let variant = self.variant.resolve_from_defaults();
 
@@ -638,7 +638,7 @@ macro_rules! impl_paint_source {
                         let acquired_node = acquired.get();
 
                         if stack.contains(acquired_node) {
-                            return Err(AcquireError::CircularReference(fragment.clone()));
+                            return Err(AcquireError::CircularReference(acquired_node.clone()));
                         }
 
                         let borrowed_node = acquired_node.borrow();
@@ -695,7 +695,7 @@ impl AsPaintSource for Gradient {
         self,
         values: &ComputedValues,
         draw_ctx: &mut DrawingCtx,
-        opacity: &UnitInterval,
+        opacity: UnitInterval,
         bbox: &BoundingBox,
     ) -> Result<bool, RenderingError> {
         let params = if self.units == GradientUnits(CoordUnits::ObjectBoundingBox) {
@@ -735,7 +735,7 @@ impl Gradient {
         &self,
         pattern: &cairo::Gradient,
         bbox: &BoundingBox,
-        opacity: &UnitInterval,
+        opacity: UnitInterval,
     ) {
         let mut affine = self.affine;
 
@@ -759,10 +759,10 @@ impl Gradient {
         self.add_color_stops_to_pattern(pattern, opacity);
     }
 
-    fn add_color_stops_to_pattern(&self, pattern: &cairo::Gradient, opacity: &UnitInterval) {
+    fn add_color_stops_to_pattern(&self, pattern: &cairo::Gradient, opacity: UnitInterval) {
         for stop in &self.stops {
             let UnitInterval(stop_offset) = stop.offset;
-            let &UnitInterval(o) = opacity;
+            let UnitInterval(o) = opacity;
             let UnitInterval(stop_opacity) = stop.opacity;
 
             pattern.add_color_stop_rgba(
