@@ -403,7 +403,6 @@ pub enum NodeType {
     ComponentTransferFunctionG,
     ComponentTransferFunctionR,
     Defs,
-    DistantLight,
     Ellipse,
     Filter,
     Group,
@@ -416,12 +415,10 @@ pub enum NodeType {
     NonRendering,
     Path,
     Pattern,
-    PointLight,
     Polygon,
     Polyline,
     RadialGradient,
     Rect,
-    SpotLight,
     Stop,
     Style,
     Svg,
@@ -440,6 +437,7 @@ pub enum NodeType {
     FeConvolveMatrix,
     FeDiffuseLighting,
     FeDisplacementMap,
+    FeDistantLight,
     FeFlood,
     FeGaussianBlur,
     FeImage,
@@ -447,7 +445,9 @@ pub enum NodeType {
     FeMergeNode,
     FeMorphology,
     FeOffset,
+    FePointLight,
     FeSpecularLighting,
+    FeSpotLight,
     FeTile,
     FeTurbulence,
 }
