@@ -322,12 +322,8 @@ impl SharedImageSurface {
         let output_surface = ImageSurface::create(cairo::Format::ARgb32, self.width, self.height)?;
 
         let cr = cairo::Context::new(&output_surface);
-        cr.rectangle(
-            bounds.x0 as f64,
-            bounds.y0 as f64,
-            (bounds.x1 - bounds.x0) as f64,
-            (bounds.y1 - bounds.y0) as f64,
-        );
+        let r = cairo::Rectangle::from(bounds);
+        cr.rectangle(r.x, r.y, r.width, r.height);
         cr.clip();
 
         cr.set_source_surface(&self.surface, 0f64, 0f64);
@@ -350,12 +346,8 @@ impl SharedImageSurface {
 
         {
             let cr = cairo::Context::new(&output_surface);
-            cr.rectangle(
-                bounds.x0 as f64,
-                bounds.y0 as f64,
-                (bounds.x1 - bounds.x0) as f64,
-                (bounds.y1 - bounds.y0) as f64,
-            );
+            let r = cairo::Rectangle::from(bounds);
+            cr.rectangle(r.x, r.y, r.width, r.height);
             cr.clip();
 
             cr.scale(x, y);
