@@ -272,7 +272,11 @@ impl PositionedSpan {
         }
     }
 
-    fn draw(&self, draw_ctx: &mut DrawingCtx, clipping: bool) -> Result<BoundingBox, RenderingError> {
+    fn draw(
+        &self,
+        draw_ctx: &mut DrawingCtx,
+        clipping: bool,
+    ) -> Result<BoundingBox, RenderingError> {
         draw_ctx.with_saved_cr(&mut |dc| {
             let cr = dc.get_cairo_context();
 
@@ -301,34 +305,35 @@ impl PositionedSpan {
                 cr.rotate(-rotation);
             }
 
-            let current_color = &self.values.color.0;
-
-            let fill_opacity = &self.values.fill_opacity.0;
+            let current_color = self.values.color.0;
 
             let res = if !clipping {
-                dc.set_source_paint_server(&self.values.fill.0, fill_opacity, &bbox, current_color)
-                    .and_then(|had_paint_server| {
-                        if had_paint_server {
-                            pangocairo::functions::update_layout(&cr, &self.layout);
-                            pangocairo::functions::show_layout(&cr, &self.layout);
-                        };
-                        Ok(())
-                    })
+                dc.set_source_paint_server(
+                    &self.values.fill.0,
+                    self.values.fill_opacity.0,
+                    &bbox,
+                    current_color,
+                )
+                .and_then(|had_paint_server| {
+                    if had_paint_server {
+                        pangocairo::functions::update_layout(&cr, &self.layout);
+                        pangocairo::functions::show_layout(&cr, &self.layout);
+                    };
+                    Ok(())
+                })
             } else {
                 Ok(())
             };
 
             if res.is_ok() {
-                let stroke_opacity = &self.values.stroke_opacity.0;
-
                 let mut need_layout_path = clipping;
 
                 let res = if !clipping {
                     dc.set_source_paint_server(
                         &self.values.stroke.0,
-                        stroke_opacity,
+                        self.values.stroke_opacity.0,
                         &bbox,
-                        &current_color,
+                        current_color,
                     )
                     .and_then(|had_paint_server| {
                         if had_paint_server {
@@ -340,17 +345,14 @@ impl PositionedSpan {
                     Ok(())
                 };
 
-                if res.is_ok() {
-                    if need_layout_path {
-                        pangocairo::functions::update_layout(&cr, &self.layout);
-                        pangocairo::functions::layout_path(&cr, &self.layout);
+                if res.is_ok() && need_layout_path {
+                    pangocairo::functions::update_layout(&cr, &self.layout);
+                    pangocairo::functions::layout_path(&cr, &self.layout);
 
-                        if !clipping {
-                            let ib =
-                                BoundingBox::new(&affine).with_ink_extents(cr.stroke_extents());
-                            cr.stroke();
-                            bbox.insert(&ib);
-                        }
+                    if !clipping {
+                        let ib = BoundingBox::new(&affine).with_ink_extents(cr.stroke_extents());
+                        cr.stroke();
+                        bbox.insert(&ib);
                     }
                 }
             }
